Learn R Programming

sperich (version 1.3-1)

dataset.all.species: Angiosperm Dataset

Description

This data set gives an example of angiosperm species and their occurence in southern america.

Usage

dataset.all.species

Arguments

format

A dataframe containing the longitude and lattitude of the occurence location as 'long' and 'lat' and the species ID as 'speciesID'.

source

Angiosperm Database

References

Morawetz, W. and Raedig, C. (2007). Angiosperm biodiversity, endemism and conservation in the Neotropics. Taxon 56:1245-1254.