Learn R Programming

sperich (version 1.3-1)

species.range: Species range estimation

Description

This function estimates the species range based on given occurences of one species.

Usage

species.range(dataset.one.species, distance, dimension, shift, 
	resolution=1, landwatermask, upperbound, cross.validation=FALSE)

Arguments

dataset.one.species
A dataset containing one species with its ID (named: speciesID) and the longitude (named: long) and latitude (named: lat) of the occurence locations of that species.
landwatermask
A grid containing the land-water-information of the observed area. If a grid cell containes no land, the value of the cell in the landwatermask is -1, otherwise it is 0. Additional, height-informations could be added for land surfaces. In this
distance
The maximum distance in which two occurences are considered as related occurences. These two occurences will be connected with an edge.
dimension
The dimension of the processed grid.
shift
The geographic coordinates of the origin of the grid.
resolution
The resolution of the grid in (geographical) degree.
upperbound
This value determines the height (based on values in 'landwatermask') which is considered to be a barrier for species distribution.
cross.validation
A logical value determining wether a cross-validation is performed.

Value

  • This function returns a grid which contains the species range information.

Details

This routine estimates the species range based on given occurences of one species through a geometric interpolation model (details in Raedig et al. 2010).

References

Raedig, C., Dorman, C.F., Hildebrandt, A. and Lautenbach, S. (2010). Reassessing Neotropical angiosperm distribution patterns based on monographic data: a geometric interpolation approach. Biodivers Conserv, 19, 1523-1546.

Examples

Run this code
##load data
data(dataset.all.species)
data(dataset.landwater)

##create grid parameters
dimension <- getDimension(dataset.all.species, resolution=1)
shift <- getShift(dataset.all.species)

##create landwatermask
landwatermask.nocoast <- createLandwatermask(dataset.landwater, 
					dimension, shift, resolution=1)

##extract datasets of one species out of database
dataset.one.species <- extract.species(dataset.all.species, 3)

##estimate species range
species.range.tmp <- species.range(dataset.one.species, distance=5, 
			dimension, shift, resolution=1, landwatermask.nocoast)

Run the code above in your browser using DataLab