Usage
species.richness.main(dataset.all.species, dataset.landwater,
dataset.height, distance.max=10, weight=0.5, resolution=1,
narrow.endemic=FALSE, narrow.endemic.limit=5, upperbound=5,
cross.validation=FALSE, fold=5, loocv.limit=10,
create.image=FALSE, image.title="Interpolated Species Richness",
directory=getwd(), filename="species.richness.png",
evaluation=FALSE, eval.title="Histogramm", adjust=FALSE,
clusterlimit=100, predefinedClusterlist=NULL, all.species=-1,
export=FALSE, drivername="GTiff", exportname="species.richness.tif",
noninterpolatedgrid=NULL, silent=TRUE)
Arguments
dataset.all.species
A dataset containing all observed species with their ID
(named: speciesID) and the longitude (named: long) and
latitude (named: lat) of their occurence location.
dataset.landwater
A dataset containing the percentage of land on
a cell of a grid. The coordinates
of the cell should be given as longitude (named: long) and
lattude (named: lat) and the percentage of land shoud be named landsum.
If the value of 'dataset.lan
dataset.height
A dataset containing the longitude and lattitude of the grid cell location
as 'long' and 'lat' and the height of the cell as 'height'. If the value of
'dataset.height' is 'NULL', the height-information has no effect on the
species richness est
distance.max
The maximum distance is used to generate a vector of distances (1:distance.max)
which will be used for species range estimation.
weight
The tuning parameter of the weighting procedure (details in Raedig et al. 2010).
resolution
The resolution of the grid in (geographical) degree.
narrow.endemic
A boolean flag that determines if only narrow endemic species
should be considered in species richness estimation.
narrow.endemic.limit
This value determines the limit of points up to
which a species is considered as narrow endemic species.
upperbound
This value determines the height which is considered to be a barrier for species distribution.
cross.validation
A logical value determining wether a cross-validation is performed. If the value is true,
the parameters narrow.endemic and narrow.endemic.limit will be ignored.
fold
The number of groups which should be created if the number of occurences is greater than loocv.limit.
loocv.limit
The limit below which the subsamples are created for a leave-one-out-cross-validation instead of a k-fold-cross-validation.
create.image
A boolean flag that determines if an image (PNG-File) should be created.
image.title
The heading of the created image.
directory
The directory in which the created files should be stored.
filename
The filename of the created PNG-Files.
evaluation
A boolean value determining wether the routine 'evaluate' is used or not. If the value is true, a PNG-File with a histogramm of the result grid will be created.
eval.title
The heading of the created histogramm.
adjust
A boolean value determining wether an adjustment of the result grid should be done or not.
clusterlimit
The limit under which values of 'species.richness' should not be used to build clusters.
Each cluster will be adjusted with an own centre of species richness.
predefinedClusterlist
A list of vectors of pixelpositions (created by 'searchClusters') which are spatial related.
The default value is NULL because the list will be created if 'adjust' is 'TRUE',
but it may be useful for robustness estimation, because the cross-va
all.species
The vector with the numbers of the species which should be mentioned. If the first value is -1,
all species in the database will be used for species richness estimation.
export
A boolean value that determines if the routine should export the results as GDAL grid map.
drivername
Determines the format of the resulting GDAL grid map.
All available drivers can be shown by using the command 'gdalDrivers()'.
exportname
The name of the created file containing the GDAL grid map.
noninterpolatedgrid
A grid containing the species occurences (could be created via function 'createNonInterpolatedGrid').
If the value of this parameter is 'NULL', it will be created if an adjustment should be done.
The parameter may be usefull to save time while proces
silent
A boolean flag that determines wether the report of status messages should be suppressed or not.