Learn R Programming

sperich (version 1.4-0)

extract.species: Species Extraktion

Description

This function extracts the datasets of one species out of a database filled with species and their occurence locations.

Usage

extract.species(dataset.all.species, species.number)

Arguments

dataset.all.species
A dataset containing all observed species with their ID (named: speciesID) and the longitude (named: long) and latitude (named: lat) of their occurence location.
species.number
The number of the species which should be extracted.

Value

  • This function returns a dataset which contains the species occurence locations.

Details

This function extracts the datasets of one species out of a database filled with species (named by their speciesID) and their occurence locations mentioned with lattitude (named lat) and longitude (named long).

Examples

Run this code
##load data
data(dataset.all.species)

#extract datasets of one species (with speciesID=3) out of database
dataset.one.species <- extract.species(dataset.all.species, 3)

Run the code above in your browser using DataLab